Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5401)

Unified Diff: chrome/common/render_messages_internal.h

Issue 506013: Combine ViewHostMsg_{Paint,Scroll}Rect into one IPC.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/render_messages.h ('k') | chrome/renderer/render_widget.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/render_messages_internal.h
===================================================================
--- chrome/common/render_messages_internal.h (revision 34937)
+++ chrome/common/render_messages_internal.h (working copy)
@@ -128,10 +128,6 @@
// render view responds with a ViewHostMsg_Thumbnail.
IPC_MESSAGE_ROUTED0(ViewMsg_CaptureThumbnail)
- // Tells the render view that a ViewHostMsg_PaintRect message was processed.
- // This signals the render view that it can send another PaintRect message.
- IPC_MESSAGE_ROUTED0(ViewMsg_PaintRect_ACK)
-
// Tells the render view to switch the CSS to print media type, renders every
// requested pages and switch back the CSS to display media type.
IPC_MESSAGE_ROUTED0(ViewMsg_PrintPages)
@@ -147,9 +143,9 @@
// JS garbage, not in purging irreplaceable objects.
IPC_MESSAGE_CONTROL0(ViewMsg_PurgeMemory)
- // Tells the render view that a ViewHostMsg_ScrollRect message was processed.
- // This signals the render view that it can send another ScrollRect message.
- IPC_MESSAGE_ROUTED0(ViewMsg_ScrollRect_ACK)
+ // Tells the render view that a ViewHostMsg_UpdateRect message was processed.
+ // This signals the render view that it can send another UpdateRect message.
+ IPC_MESSAGE_ROUTED0(ViewMsg_UpdateRect_ACK)
// Message payload includes:
// 1. A blob that should be cast to WebInputEvent
@@ -993,16 +989,11 @@
navigating to a POST again and we're going to
show the POST interstitial */ )
- // Sent to paint part of the view. In response to this message, the host
- // generates a ViewMsg_PaintRect_ACK message.
- IPC_MESSAGE_ROUTED1(ViewHostMsg_PaintRect,
- ViewHostMsg_PaintRect_Params)
+ // Sent to update part of the view. In response to this message, the host
+ // generates a ViewMsg_UpdateRect_ACK message.
+ IPC_MESSAGE_ROUTED1(ViewHostMsg_UpdateRect,
+ ViewHostMsg_UpdateRect_Params)
- // Sent to scroll part of the view. In response to this message, the host
- // generates a ViewMsg_ScrollRect_ACK message.
- IPC_MESSAGE_ROUTED1(ViewHostMsg_ScrollRect,
- ViewHostMsg_ScrollRect_Params)
-
// Acknowledges receipt of a ViewMsg_HandleInputEvent message.
// Payload is a WebInputEvent::Type which is the type of the event, followed
// by an optional WebInputEvent which is provided only if the event was not
« no previous file with comments | « chrome/common/render_messages.h ('k') | chrome/renderer/render_widget.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698